@@ -5,14 +5,14 @@ from gdsfactory.config import logger
 from gdsfactory.get_factories import get_cells
 from gdsfactory.pdk import Pdk
 
-from sky130 import components
+from sky130 import components, pcells
 from sky130.config import PATH, module_path
 from sky130.layers import LAYER, LAYER_COLORS, LAYER_STACK
 from sky130.tech import cross_sections
 
-__version__ = "0.0.15"
+__version__ = "0.1.0"
 
-cells = get_cells(components)
+cells = get_cells([components, pcells])
 PDK = Pdk(
     name="sky130",
     cells=cells,
@@ -30,11 +30,11 @@ logger.info(f"load sky130 PDK {__version__!r} installed at {str(module_path)!r}"
 __all__ = ["cells", "PDK"]
 
 if __name__ == "__main__":
-    # f = PDK.cells
-    # print(f.keys())
-    import gdsfactory as gf
+    f = PDK.cells
+    print(f.keys())
+    # import gdsfactory as gf
 
-    script = gf.write_cells.get_import_gds_script("gds", module="sky130.components")
-    filepath = pathlib.Path("components2.py")
-    filepath.write_text(script)
-    print(script)
+    # script = gf.write_cells.get_import_gds_script("gds", module="sky130.components")
+    # filepath = pathlib.Path("components2.py")
+    # filepath.write_text(script)
+    # print(script)
