@@ -1080,4 +1080,4 @@ if __name__ == "__main__":
     ax.plot(analysis.DRAIN)
     ax.legend(("GATE", "DRAIN"))
     plt.tight_layout()
-    plt.show()
+    plt.show(show_ports=True)
